@@ -8,9 +8,9 @@ from subprocess import CalledProcessError
 
 import pytest
 from generate_samples import create_package, run_command
+from packaging.version import Version
 
 from cx_Freeze._compat import BUILD_EXE_DIR
-from cx_Freeze._packaging import Version
 from cx_Freeze.winversioninfo import COMMENTS_MAX_LEN, VersionInfo, main_test
 
 SOURCE_SIMPLE_TEST = """
@@ -131,7 +131,7 @@ class TestVersionInfo:
         with pytest.raises(FileNotFoundError):
             version.stamp("test.exe")
 
-    @pytest.fixture()
+    @pytest.fixture
     def tmp_test(self, tmp_path) -> Path:
         """Generate a executable file test.exe to be used in tests."""
         create_package(tmp_path, SOURCE_SIMPLE_TEST)
